summaryrefslogtreecommitdiffstats
path: root/korn/account_input.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/account_input.h')
-rw-r--r--korn/account_input.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/korn/account_input.h b/korn/account_input.h
index 8cff757c..548db498 100644
--- a/korn/account_input.h
+++ b/korn/account_input.h
@@ -106,24 +106,24 @@ public:
/**
* Constructor
*
* @param tqparent The tqparent widget
* @param title The title that appears on the screen
* @param type The type of TextEdit which is used
* @param defaul The default value of this object
* @param configName The name it has in the configuration box.
*/
- TextInput( TQWidget *tqparent, const TQString& title, Type type, const TQString& defaul, const TQString& configName );
+ TextInput( TQWidget *parent, const TQString& title, Type type, const TQString& defaul, const TQString& configName );
/**
* Constructor. Use this one if you want to ensure a number is inserted.
*
* @param tqparent The tqparent widget
* @param title The title that appears on the screen
* @param min The minimum value that can be inserted
* @param max The maximum value that can be inserted
* @param defaul The default value of this object
* @param configName The name it has in the configuration box.
*/
- TextInput( TQWidget *tqparent, const TQString& title, int min, int max, const TQString& defaul, const TQString& configName );
+ TextInput( TQWidget *parent, const TQString& title, int min, int max, const TQString& defaul, const TQString& configName );
/**
* Destructor
*/
@@ -163,12 +163,12 @@ class URLInput : public AccountInput
public:
/**
* Constructor
* @param tqparent The tqparent of this object
* @param title The title of the label next to the URL.
* @param defaul The default value
* @param configName The name of the configuration entry
*/
- URLInput( TQWidget *tqparent, const TQString& title, const TQString& defaul, const TQString& configName );
+ URLInput( TQWidget *parent, const TQString& title, const TQString& defaul, const TQString& configName );
/**
* Destructor
*/
@@ -210,14 +210,14 @@ public:
/**
* Constructor
*
* @param tqparent The tqparent of the widgets which are created
* @param title The title next to the combo box
* @param list A mapping which maps a value in the configuration to a (translated) entry in the
* combo box.
* @param default The default value of the combo box.
* @param configName The name in which the option is saved.
*/
- ComboInput( TQWidget *tqparent, const TQString& title, const TQMap<TQString,TQString>& list,
+ ComboInput( TQWidget *parent, const TQString& title, const TQMap<TQString,TQString>& list,
const TQString& defaul, const TQString& configName );
/**
* Destructor
@@ -264,12 +264,12 @@ public:
/**
* Constructor
*
* @param tqparent The tqparent for the objects which are created
* @param title The title of the checkbox
* @param defaul The default value ("true" for checked, "false" otherwise")
* @param configName The name of the configuration entry of this object
*/
- CheckboxInput( TQWidget *tqparent, const TQString& title, const TQString& defaul, const TQString& configName );
+ CheckboxInput( TQWidget *parent, const TQString& title, const TQString& defaul, const TQString& configName );
/**
* Destructor
*/
@@ -106,24 +106,24 @@ public:
* Constructor
*
- * @param tqparent The tqparent widget
+ * @param parent The parent widget
* @param title The title that appears on the screen
* @param type The type of TextEdit which is used
@@ -106,24 +106,24 @@ public:
* Constructor. Use this one if you want to ensure a number is inserted.
*
- * @param tqparent The tqparent widget
+ * @param parent The parent widget
* @param title The title that appears on the screen
* @param min The minimum value that can be inserted
@@ -163,12 +163,12 @@ class URLInput : public AccountInput
/**
* Constructor
- * @param tqparent The tqparent of this object
+ * @param parent The parent of this object
* @param title The title of the label next to the URL.
* @param defaul The default value
@@ -210,14 +210,14 @@ public:
* Constructor
*
- * @param tqparent The tqparent of the widgets which are created
+ * @param parent The parent of the widgets which are created
* @param title The title next to the combo box
* @param list A mapping which maps a value in the configuration to a (translated) entry in the
@@ -264,12 +264,12 @@ public:
* Constructor
*
- * @param tqparent The tqparent for the objects which are created
+ * @param parent The parent for the objects which are created
* @param title The title of the checkbox
* @param defaul The default value ("true" for checked, "false" otherwise")